@@ -1,5 +1,5 @@
 #!/bin/bash
-#  Copyright (C) 2000-2006 SWsoft. All rights reserved.
+#  Copyright (C) 2000-2007 SWsoft. All rights reserved.
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -26,24 +26,6 @@
 #       Sets host name for this VE. Modifies /etc/hosts and
 #       /etc/sysconfig/network (in RedHat) or /etc/rc.config (in SuSE)
 
-function set_host()
-{
-	local cfgfile="$1"
-	local var=$2
-	local val=$3
-	local host=
-
-	[ -z "${val}" ] && return 0
-        if grep -q -E "[[:space:]]${val}" ${cfgfile} 2>/dev/null; then
-                return;
-        fi
-	if echo "${val}" | grep "\." >/dev/null 2>&1; then
-		host=${val%%.*}
-	fi
-	host=" ${val} ${host}"
-	put_param2 "${cfgfile}" "${var}" "${host} localhost localhost.localdomain"
-}
-
 function set_hostname()
 {
 	local cfgfile=$1
@@ -54,7 +36,7 @@ function set_hostname()
 	hostname ${hostname}
 }
 
-set_host /etc/hosts "127.0.0.1" "${HOSTNM}"
+change_hostname /etc/hosts "${HOSTNM}" "${IP_ADDR}"
 set_hostname /etc/hostname "${HOSTNM}"
 
 exit 0
