@@ -60,7 +60,7 @@ BEGIN { srand(); }
 		line = line " "  ar[i];
 	}
 	print line;
-} 
+}
 ' > ${file}.$$ && /bin/mv -f ${file}.$$ ${file}
 	/bin/rm -f ${file}.$$ 2>/dev/null
 }
@@ -72,14 +72,14 @@ function disableroot()
 	[ -f "$file" ] || return 0
 
 	if /bin/grep -q "^root::" "${file}" 2>/dev/null; then
-		/bin/sed 's/^root::/root:!!:/g' < ${file} > ${file}.$$ && \
+		/bin/sed 's/^root::/root:!!:/g' < ${file} > ${file}.$$ &&
 			/bin/mv -f ${file}.$$ ${file}
 		/bin/rm -f ${file}.$$ 2>/dev/null
 	fi
 }
 
 [ -z "${VE_ROOT}" ] && return 1
-randcrontab 
+randcrontab
 disableroot
 
 exit 0
