@@ -49,7 +49,7 @@ function fix_ifup()
 	if grep -q 'if \[ "\${DEVICE}" = "lo" \]; then' ${file} 2>/dev/null
 	then
 		${CP} ${file} ${file}.$$ || return 1
-		/bin/sed -e 's/if \[ "\${DEVICE}" = "lo" \]; then/if \[ "${IPADDR}" = "127.0.0.1" \]; then/g' < ${file} > ${file}.$$ && \
+		/bin/sed -e 's/if \[ "\${DEVICE}" = "lo" \]; then/if \[ "${IPADDR}" = "127.0.0.1" \]; then/g' < ${file} > ${file}.$$ &&
 			mv -f ${file}.$$ ${file}
 		rm -f ${file}.$$ 2>/dev/null
 	fi
@@ -108,7 +108,7 @@ function create_config()
 	echo "DEVICE=${VENET_DEV}:${ifnum}
 ONBOOT=yes
 IPADDR=${ip}
-NETMASK=255.255.255.255" > ${IFCFG_DIR}/bak/${VENET_DEV_CFG}:${ifnum} || \
+NETMASK=255.255.255.255" > ${IFCFG_DIR}/bak/${VENET_DEV_CFG}:${ifnum} ||
 	error "Unable to create interface config file" ${VZ_FS_NO_DISK_SPACE}
 }
 
@@ -125,9 +125,9 @@ function add_ip6()
 function get_all_aliasid()
 {
 	IFNUM=-1
-	
+
 	cd ${IFCFG_DIR} || return 1
-	IFNUMLIST=`ls -1 bak/${VENET_DEV_CFG}:* 2>/dev/null | \
+	IFNUMLIST=`ls -1 bak/${VENET_DEV_CFG}:* 2>/dev/null |
 		sed "s/.*${VENET_DEV_CFG}://"`
 }
 
@@ -137,7 +137,7 @@ function get_aliasid_by_ip()
 	local idlist
 
 	cd ${IFCFG_DIR} || return 1
-	IFNUM=`grep -l "IPADDR=${ip}$" ${VENET_DEV_CFG}:* | head -n 1 | \
+	IFNUM=`grep -l "IPADDR=${ip}$" ${VENET_DEV_CFG}:* | head -n 1 |
 		sed -e 's/.*:\([0-9]*\)$/\1/'`
 }
 
@@ -148,7 +148,7 @@ function get_free_aliasid()
 	[ -z "${IFNUMLIST}" ] && get_all_aliasid
 	while test -z ${found}; do
 		let IFNUM=IFNUM+1
-		echo "${IFNUMLIST}" | grep -q -E "^${IFNUM}$" 2>/dev/null || \
+		echo "${IFNUMLIST}" | grep -q -E "^${IFNUM}$" 2>/dev/null ||
 			found=1
 	done
 }
@@ -163,7 +163,7 @@ function backup_configs()
 
 	cd ${IFCFG_DIR} || return 1
 	if ls ${VENET_DEV_CFG}:* > /dev/null 2>&1; then
-		${CP} ${VENET_DEV_CFG}:* ${IFCFG_DIR}/bak/ || \
+		${CP} ${VENET_DEV_CFG}:* ${IFCFG_DIR}/bak/ ||
 			error "Unable to backup intrface config files" ${VZ_FS_NO_DISK_SPACE}
 	fi
 }
@@ -172,14 +172,14 @@ function move_configs()
 {
 	cd ${IFCFG_DIR} || return 1
 	rm -rf ${VENET_DEV_CFG}:*
-	mv -f bak/* ${IFCFG_DIR}/ >/dev/null 2>&1 
+	mv -f bak/* ${IFCFG_DIR}/ >/dev/null 2>&1
 	rm -rf ${IFCFG_DIR}/bak
 }
 
 function add_ip()
 {
 	local ip
-	local new_ips 
+	local new_ips
 	local if_restart=
 
 	# In case we are starting VE
@@ -219,12 +219,12 @@ function add_ip()
 	move_configs
 	if [ "x${VE_STATE}" = "xrunning" ]; then
 		# synchronyze config files & interfaces
-		if [ "${NETWORKRESTART}" = "yes" ]; then 
+		if [ "${NETWORKRESTART}" = "yes" ]; then
 			/etc/init.d/network restart
 		elif [ -n "${if_restart}" ]; then
 			ifup ${VENET_DEV}
 		else
-			cd /etc/sysconfig/network-scripts && \
+			cd /etc/sysconfig/network-scripts &&
 				./ifup-aliases ${VENET_DEV}
 		fi
 	fi
