@@ -1,12 +1,20 @@
 #!/bin/bash
-# Copyright (C) 2000-2005 SWsoft. All rights reserved.
+#  Copyright (C) 2000-2007 SWsoft. All rights reserved.
 #
-# This file may be distributed under the terms of the Q Public License
-# as defined by Trolltech AS of Norway and appearing in the file
-# LICENSE.QPL included in the packaging of this file.
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
 # This script configure IP alias(es) inside VE for SuSE-9
 #
@@ -20,8 +28,6 @@
 #
 # this should set up networking for SuSE-based VE
 VENET_DEV=venet0
-FAKEGATEWAYNET=191.255.255.0
-FAKEGATEWAY=191.255.255.1
 IFCFG_DIR=/etc/sysconfig/network/
 IFCFG=${IFCFG_DIR}/ifcfg-${VENET_DEV}
 ROUTES=${IFCFG_DIR}/ifroute-${VENET_DEV}
@@ -43,16 +49,17 @@ function init()
 BOOTPROTO=static
 BROADCAST=0.0.0.0
 NETMASK=255.255.255.255
-IPADDR=127.0.0.1" > ${IFCFG} || \
+IPADDR=127.0.0.1" > ${IFCFG} ||
 	error "Can't write to file ${IFCFG_DIR}/${VENET_DEV_CFG}" ${VZ_FS_NO_DISK_SPACE}
 
-	if ! grep -q -E "${FAKEGATEWAYNET}[[:space:]]0.0.0.0[[:space:]]255.255.255.0[[:space:]]${VENET_DEV}" ${ROUTES};
+	remove_fake_old_route ${ROUTES}
+	if ! grep -q -E "${FAKEGATEWAYNET}[[:space:]]0.0.0.0[[:space:]]255.255.255.0[[:space:]]${VENET_DEV}" ${ROUTES} 2>/dev/null;
 	then
-		echo "${FAKEGATEWAYNET} 0.0.0.0 255.255.255.0   ${VENET_DEV}" >> ${ROUTES}
+		echo "${FAKEGATEWAYNET}	0.0.0.0 255.255.255.0	${VENET_DEV}" >> ${ROUTES}
 	fi
-	if ! grep -q -E "default[[:space:]]${FAKEGATEWAY}[[:space:]]0.0.0.0[[:space:]]${VENET_DEV}" ${ROUTES};
+	if ! grep -q -E "default[[:space:]]${FAKEGATEWAY}[[:space:]]0.0.0.0[[:space:]]${VENET_DEV}" ${ROUTES} 2>/dev/null;
 	then
-		echo "default ${FAKEGATEWAY}    0.0.0.0 ${VENET_DEV}" >> ${ROUTES}
+		echo "default ${FAKEGATEWAY}	0.0.0.0	${VENET_DEV}" >> ${ROUTES}
 	fi
 	# Set up /etc/hosts
 	if [ ! -f ${HOSTFILE} ]; then
@@ -66,7 +73,7 @@ function create_config()
 	local ifnum=$2
 
 	echo "IPADDR_${ifnum}=${ip}
-LABEL_${ifnum}=${ifnum}" >> ${IFCFG} || \
+LABEL_${ifnum}=${ifnum}" >> ${IFCFG} ||
 	error "Can't write to file ${IFCFG_DIR}/${VENET_DEV_CFG}" ${VZ_FS_NO_DISK_SPACE}
 }
 
@@ -76,6 +83,9 @@ function add_ip()
 	local ifnum=-1
 
 	if [ "x${IPDELALL}" = "xyes" -o "x${VE_STATE}" = "xstarting" ]; then
+		rm -f ${IFCFG} 2>/dev/null
+	fi
+	if [ ! -f "${IFCFG}" ]; then
 		init
 	fi
 	get_aliases
