@@ -76,10 +76,12 @@ int fs_create(envid_t veid, fs_param *fs, tmpl_param *tmpl, dq_param *dq,
 	char *arg[2];
 	char *env[4];
 	int quota = 0;
-	
-	snprintf(tarball, sizeof(tarball), "%s/%s.tar.gz", fs->tmpl, tar_nm);
+
+	snprintf(tarball, sizeof(tarball), "%s/%s.tar", fs->tmpl, tar_nm);
+	if (!stat_file(tarball))
+		snprintf(tarball, sizeof(tarball), "%s/%s.tar.gz", fs->tmpl, tar_nm);
 	if (!stat_file(tarball)) {
-		logger(-1, 0, "Cached os template %s not found",	tarball);
+		logger(-1, 0, "Cached os template %s not found", tarball);
 		return VZ_PKGSET_NOT_FOUND;
 	}
 	/* Lock VE area */
@@ -99,7 +101,7 @@ int fs_create(envid_t veid, fs_param *fs, tmpl_param *tmpl, dq_param *dq,
 		ret = VZ_FS_NEW_VE_PRVT;
 		goto err;
 	}
-	if (dq != NULL && 
+	if (dq != NULL &&
 		dq->enable == YES &&
 		dq->diskspace != NULL &&
 		dq->diskinodes != NULL)
@@ -149,7 +151,7 @@ err:
 int vps_create(vps_handler *h, envid_t veid, vps_param *vps_p, vps_param *cmd_p,
 	struct mod_action *action)
 {
-	int ret;
+	int ret = 0;
 	char tar_nm[256];
 	char src[STR_SIZE];
 	char dst[STR_SIZE];
@@ -182,7 +184,7 @@ int vps_create(vps_handler *h, envid_t veid, vps_param *vps_p, vps_param *cmd_p,
 		snprintf(src, sizeof(src),  VPS_CONF_DIR "ve-%s.conf-sample",
 			vps_p->opt.config);
 		/* Do not use config if VE config exists */
-		if (!cfg_exists && stat_file(src)) 
+		if (!cfg_exists && stat_file(src))
 			sample_config = vps_p->opt.config;
 	}
 	if (sample_config != NULL) {
@@ -198,15 +200,27 @@ int vps_create(vps_handler *h, envid_t veid, vps_param *vps_p, vps_param *cmd_p,
 	}
 	merge_vps_param(vps_p, cmd_p);
 	if (check_var(fs->tmpl, "TEMPLATE is not set"))
-		return VZ_VE_TMPL_NOTSET;
-	if (check_var(fs->private, "VE_PRIVATE is not set"))
-		return VZ_VE_PRIVATE_NOTSET;
-	if (check_var(fs->root, "VE_ROOT is not set"))
-		return VZ_VE_ROOT_NOTSET;
-	if (stat_file(fs->private)) {
+		ret = VZ_VE_TMPL_NOTSET;
+	else if (check_var(fs->private, "VE_PRIVATE is not set"))
+		ret = VZ_VE_PRIVATE_NOTSET;
+	else if (check_var(fs->root, "VE_ROOT is not set"))
+		ret = VZ_VE_ROOT_NOTSET;
+	else if (stat_file(fs->private)) {
 		logger(-1, 0, "Private area already exists in %s", fs->private);
-		return VZ_FS_PRVT_AREA_EXIST;
+		ret = VZ_FS_PRVT_AREA_EXIST;
 	}
+
+	if ((ret == 0) && (cmd_p->res.name.name)) {
+		ret = set_name(veid, cmd_p->res.name.name, cmd_p->res.name.name);
+	}
+
+	/* Error? Clean up and exit */
+	if (ret != 0) {
+		if (sample_config != NULL)
+			unlink(dst);
+		return ret;
+	}
+
 	if (action != NULL && action->mod_count) {
 		ret = mod_setup(h, veid, 0, 0, action, vps_p);
 	} else {
@@ -270,7 +284,7 @@ int vps_postcreate(envid_t veid, fs_param *fs, tmpl_param *tmpl)
 	char *arg[2];
 	char *env[3];
 	int ret;
- 
+
 	if (check_var(fs->root, "VE_ROOT is not set"))
 		return VZ_VE_ROOT_NOTSET;
 	dist_name = get_dist_name(tmpl);
