@@ -101,7 +101,7 @@ int stat_file(const char *file)
 	struct stat st;
 
 	if (stat(file, &st)) {
-		if (errno != ENOENT) 
+		if (errno != ENOENT)
 			return -1;
 		return 0;
 	}
@@ -156,6 +156,11 @@ int parse_ul(const char *str, unsigned long *val)
 {
 	char *tail;
 
+	if (!strcmp(str, "unlimited")) {
+		*val = LONG_MAX;
+		return 0;
+	}
+
 	errno = 0;
 	*val = (int)strtoul(str, (char **)&tail, 10);
 	if (*tail != '\0' || errno == ERANGE)
@@ -307,7 +312,7 @@ char *subst_VEID(envid_t veid, char *src)
 	char str[STR_SIZE];
 	char *sp, *se;
 	int r, len, veidlen;
-	
+
 	if (src == NULL)
 		return NULL;
 	/* Skip end '/' */
@@ -437,16 +442,21 @@ int get_lowmem(unsigned long long *mem)
 		logger(-1, errno, "Cannot open " PROCMEM);
 		return -1;
 	}
+	*mem = 0;
 	while (fgets(str, sizeof(str), fd)) {
-		if (sscanf(str, "LowTotal: %llu", mem) == 1) {
-			fclose(fd);
-			*mem *= 1024;
-			return 0;
-		}
+		if (sscanf(str, "LowTotal: %llu", mem) == 1)
+			break;
+		/* Use MemTotal in case LowTotal not found */
+		sscanf(str, "MemTotal: %llu", mem);
 	}
-	logger(-1, errno, "LowTotal: is not found in" PROCMEM);
 	fclose(fd);
-	return -1;
+	if (*mem == 0) {
+		fprintf(stderr, "Neither LowTotal nor MemTotal found in the "
+				PROCMEM "\n");
+		return -1;
+	}
+	*mem *= 1024;
+	return 0;
 }
 
 char *get_file_name(char *str)
@@ -508,7 +518,7 @@ int set_not_blk(int fd)
 
 /** Close all fd.
  * @param close_std	flag for closing the [0-2] fds
- * @param ...		list of fds are skiped, (-1 is the end mark) 
+ * @param ...		list of fds are skiped, (-1 is the end mark)
 */
 void close_fds(int close_std, ...)
 {
@@ -518,7 +528,7 @@ void close_fds(int close_std, ...)
 
 	max = sysconf(_SC_OPEN_MAX);
 	if (max < NR_OPEN)
-		max = NR_OPEN; 
+		max = NR_OPEN;
 	if (close_std) {
 		fd = open("/dev/null", O_RDWR);
 		if (fd != -1) {
@@ -539,7 +549,7 @@ void close_fds(int close_std, ...)
 	va_end(ap);
 	for (fd = 3; fd < max; fd++) {
 		for (i = 0; skip_fds[i] != fd && skip_fds[i] != -1; i++);
-		if (skip_fds[i] == fd) 
+		if (skip_fds[i] == fd)
 			continue;
 		close(fd);
 	}
@@ -561,7 +571,7 @@ int move_config(int veid, int action)
 	snprintf(conf, sizeof(conf), VPS_CONF_DIR "%d." MOUNT_PREFIX, veid);
 	snprintf(newconf, sizeof(newconf), "%s." DESTR_PREFIX, conf);
 	action == BACKUP ? rename(conf, newconf) : unlink(newconf);
-	
+
 	snprintf(conf, sizeof(conf), VPS_CONF_DIR "%d." UMOUNT_PREFIX, veid);
 	snprintf(newconf, sizeof(newconf), "%s." DESTR_PREFIX, conf);
 	action == BACKUP ? rename(conf, newconf) : unlink(newconf);
