@@ -29,11 +29,10 @@
 #include "util.h"
 #include "logger.h"
 
-LOG_DATA
-
-void usage()
+void usage(int rc)
 {
-	printf("Usage: vzmemcheck [-v] [-A]\n");
+	fprintf(rc ? stderr : stdout, "Usage: vzmemcheck [-v] [-A]\n");
+	exit(rc);
 }
 
 void header(int verbose, int param)
@@ -115,7 +114,7 @@ int calculate(int numerator, int verbose)
 				ru_utl.mem_swap *= k;
 				ru_utl.alloc_mem *= k;
 			}
-			shift_ubs_param(&ub_s);	
+			shift_ubs_param(&ub_s);
 			if (!calc_ve_commitment(&ub_s, &ru_comm, &mem,
 				 numerator))
 			{
@@ -196,9 +195,9 @@ int main(int argc, char **argv)
 			numerator = 1;
 			break;
 		case 'h':
-			usage();
-			exit(1);
-			break;
+			usage(0);
+		default:
+			usage(1);
 		}
 	}
 	init_log(NULL, 0, 0, 0, 0, NULL);
